@@ -4,6 +4,7 @@ import os
 
 import cv2
 import numpy as np
+from PIL import Image, ImageFile
 
 from maps4fs.generator.component.base.component import Component
 from maps4fs.generator.settings import Parameters
@@ -67,6 +68,7 @@ class ImageComponent(Component):
         mask_by: int = 255,
         erode_kernel: int | None = 3,
         erode_iter: int | None = 1,
+        flatten_to: int | None = None,
     ) -> np.ndarray:
         """Subtracts a value from the image where the mask is equal to the mask by value.
 
@@ -77,6 +79,7 @@ class ImageComponent(Component):
             mask_by (int, optional): The value to mask by. Defaults to 255.
             erode_kernel (int, optional): The kernel size for the erosion. Defaults to 3.
             erode_iter (int, optional): The number of iterations for the erosion. Defaults to 1.
+            flatten_to_mean (bool, optional): Whether to flatten the image to the mean value.
 
         Returns:
             np.ndarray: The image with the subtracted value.
@@ -90,6 +93,10 @@ class ImageComponent(Component):
             ).astype(bool)
 
         image[mask] = image[mask] - subtract_by
+
+        if flatten_to:
+            image[mask] = flatten_to
+
         return image
 
     @staticmethod
@@ -190,7 +197,7 @@ class ImageComponent(Component):
             raise ValueError("Data and mask must have the same dimensions.")
 
         # Create a blurred version of the data
-        blurred_data = cv2.GaussianBlur(data, (blur_radius, blur_radius), sigmaX=3)
+        blurred_data = cv2.GaussianBlur(data, (blur_radius, blur_radius), sigmaX=10)
 
         # Combine the blurred data with the original data using the mask
         result = np.where(mask == 255, blurred_data, data)
@@ -231,3 +238,35 @@ class ImageComponent(Component):
         edge_mask = cv2.subtract(bigger_mask, smaller_mask)
 
         return self.blur_by_mask(data, edge_mask)
+
+    @staticmethod
+    def convert_png_to_dds(input_png_path: str, output_dds_path: str):
+        """Convert a PNG file to DDS format using PIL
+
+        Arguments:
+            input_png_path (str): Path to input PNG file
+            output_dds_path (str): Path for output DDS file
+
+        Raises:
+            FileNotFoundError: If the input PNG file does not exist.
+            RuntimeError: If the DDS conversion fails.
+        """
+        if not os.path.exists(input_png_path):
+            raise FileNotFoundError(f"Input PNG file not found: {input_png_path}")
+
+        try:
+            ImageFile.LOAD_TRUNCATED_IMAGES = True
+
+            with Image.open(input_png_path) as img:
+                # Convert to RGB if needed (DDS works better with RGB)
+                if img.mode == "RGBA":
+                    # Create RGB version on white background
+                    rgb_img = Image.new("RGB", img.size, (255, 255, 255))
+                    rgb_img.paste(img, mask=img.split()[-1])  # Use alpha as mask
+                    img = rgb_img
+                elif img.mode != "RGB":
+                    img = img.convert("RGB")
+
+                img.save(output_dds_path, format="DDS")
+        except Exception as e:
+            raise RuntimeError(f"DDS conversion failed: {e}")
