@@ -7,6 +7,7 @@ import os
 import shutil
 import warnings
 from collections import defaultdict
+from time import perf_counter
 from typing import Any, Callable, Generator, Optional
 
 import cv2
@@ -168,6 +169,14 @@ class Texture(ImageComponent):
         """
         return [layer for layer in self.layers if layer.indoor]
 
+    def get_building_category_layers(self) -> list[Layer]:
+        """Returns layers which have building category defined.
+
+        Returns:
+            list[Layer]: List of layers which have building category defined.
+        """
+        return [layer for layer in self.layers if layer.building_category is not None]
+
     def process(self) -> None:
         """Processes the data to generate textures."""
         self._prepare_weights()
@@ -469,8 +478,11 @@ class Texture(ImageComponent):
             self._draw_layer(layer, info_layer_data, layer_image)  # type: ignore
             self._add_roads(layer, info_layer_data)
 
-            output_image = cv2.bitwise_and(layer_image, mask)  # type: ignore
-            cumulative_image = cv2.bitwise_or(cumulative_image, output_image)  # type: ignore
+            if not layer.external:
+                output_image = cv2.bitwise_and(layer_image, mask)  # type: ignore
+                cumulative_image = cv2.bitwise_or(cumulative_image, output_image)  # type: ignore
+            else:
+                output_image = layer_image  # type: ignore
 
             cv2.imwrite(layer_path, output_image)
             self.logger.debug("Texture %s saved.", layer_path)
@@ -804,6 +816,7 @@ class Texture(ImageComponent):
 
         ox_settings.use_cache = self.map.texture_settings.use_cache
         ox_settings.requests_timeout = 30
+        ox_settings.log_console = True
 
         objects = self.fetch_osm_data(tags)
         if objects is None or objects.empty:
@@ -832,7 +845,14 @@ class Texture(ImageComponent):
                     warnings.simplefilter("ignore", FutureWarning)
                     objects = ox.features_from_xml(self.map.custom_osm, tags=tags)
             else:
+                ox_start_time = perf_counter()
+                self.logger.info("------------------------------------------")
+                self.logger.info("Fetching OSM data for tags: %s.", tags)
                 objects = ox.features_from_bbox(bbox=self.new_bbox, tags=tags)
+                self.logger.info("Fetched %s objects for tags: %s.", len(objects), tags)
+                ox_end_time = perf_counter()
+                self.logger.info("OSM data fetch time: %.2f seconds.", ox_end_time - ox_start_time)
+                self.logger.info("------------------------------------------")
         except Exception as e:
             self.logger.debug("Error fetching objects for tags: %s. Error: %s.", tags, e)
             return None
