@@ -40,7 +40,7 @@ logger.info(
 )
 
 TEMPLATES_STRUCTURE = {
-    "fs25": ["texture_schemas", "tree_schemas", "map_templates"],
+    "fs25": ["texture_schemas", "tree_schemas", "buildings_schemas", "map_templates"],
     "fs22": ["texture_schemas", "map_templates"],
 }
 
@@ -51,11 +51,19 @@ def ensure_templates():
     If MFS_TEMPLATES_DIR is empty or doesn't exist, clone the maps4fsdata
     repository and run the preparation script to populate it.
     """
-
     # Check if templates directory exists and has content
-    if os.path.exists(MFS_TEMPLATES_DIR) and os.listdir(MFS_TEMPLATES_DIR):
-        logger.info("Templates directory already exists and contains data: %s", MFS_TEMPLATES_DIR)
-        return
+    if os.path.exists(MFS_TEMPLATES_DIR):  # and os.listdir(MFS_TEMPLATES_DIR):
+        logger.info("Templates directory already exists: %s", MFS_TEMPLATES_DIR)
+
+        files = [
+            entry
+            for entry in os.listdir(MFS_TEMPLATES_DIR)
+            if os.path.isfile(os.path.join(MFS_TEMPLATES_DIR, entry))
+        ]
+
+        if files:
+            logger.info("Templates directory contains files and will not be modified.")
+            return
 
     logger.info("Templates directory is empty or missing, preparing data...")
 
@@ -82,15 +90,31 @@ def ensure_templates():
                 text=True,
             )
 
-            # Make the preparation script executable
-            prep_script = os.path.join(clone_dir, "prepare_data.sh")
+            if os.name == "nt":
+                logger.info("Detected Windows OS, running PowerShell preparation script...")
+                prep_script = os.path.join(clone_dir, "prepare_data.ps1")
+                for_subprocess = [
+                    "powershell",
+                    "-ExecutionPolicy",
+                    "Bypass",
+                    "-File",
+                    "prepare_data.ps1",
+                ]
+            else:
+                logger.info("Detected non-Windows OS, running bash preparation script...")
+                prep_script = os.path.join(clone_dir, "prepare_data.sh")
+                for_subprocess = ["./prepare_data.sh"]
+
             if os.path.exists(prep_script):
-                os.chmod(prep_script, 0o755)
+                try:
+                    os.chmod(prep_script, 0o755)
+                except Exception as e:
+                    logger.warning("Could not set execute permissions on script: %s", str(e))
 
                 logger.info("Running data preparation script...")
                 # Run the preparation script from the cloned directory
                 subprocess.run(
-                    ["./prepare_data.sh"], cwd=clone_dir, check=True, capture_output=True, text=True
+                    for_subprocess, cwd=clone_dir, check=True, capture_output=True, text=True
                 )
 
                 # Copy the generated data directory to templates directory
@@ -140,6 +164,27 @@ def ensure_template_subdirs() -> None:
     logger.info("Templates directory is ready at: %s", MFS_TEMPLATES_DIR)
 
 
+def reload_templates() -> None:
+    """Reload templates by removing existing files and re-preparing them.
+    Does not affect nested directories containing user data.
+    If needed, the files should be removed manually.
+    """
+    logger.info("Reloading templates...")
+    # Remove files from the templates directory.
+    # But do not remove nested directories, because they contain user data.
+    # Only remove files in the top-level templates directory.
+    for item in os.listdir(MFS_TEMPLATES_DIR):
+        item_path = os.path.join(MFS_TEMPLATES_DIR, item)
+        if os.path.isfile(item_path):
+            try:
+                os.remove(item_path)
+            except Exception as e:
+                logger.warning("Could not remove file %s: %s", item_path, str(e))
+    ensure_templates()
+    ensure_template_subdirs()
+    logger.info("Templates reloaded successfully.")
+
+
 ensure_templates()
 ensure_template_subdirs()
 
