@@ -5,9 +5,11 @@ template file and specific settings for map generation."""
 from __future__ import annotations
 
 import os
+from typing import Callable
 
 import maps4fs.generator.config as mfscfg
 from maps4fs.generator.component.background import Background
+from maps4fs.generator.component.building import Building
 from maps4fs.generator.component.config import Config
 from maps4fs.generator.component.grle import GRLE
 from maps4fs.generator.component.i3d import I3d
@@ -37,6 +39,7 @@ class Game:
     _texture_schema_file: str | None = None
     _grle_schema_file: str | None = None
     _tree_schema_file: str | None = None
+    _buildings_schema_file: str | None = None
     _i3d_processing: bool = True
     _plants_processing: bool = True
     _environment_processing: bool = True
@@ -45,7 +48,7 @@ class Game:
     _mesh_processing: bool = True
 
     # Order matters! Some components depend on others.
-    components = [Satellite, Texture, Background, GRLE, I3d, Config]
+    components = [Satellite, Texture, Background, GRLE, I3d, Config, Building]
 
     def __init__(self, map_template_path: str | None = None):
         if map_template_path:
@@ -72,6 +75,11 @@ class Game:
         else:
             self._tree_schema = os.path.join(mfscfg.MFS_TEMPLATES_DIR, self._tree_schema_file)  # type: ignore
 
+        if not self._buildings_schema_file:
+            self._buildings_schema_file = None
+        else:
+            self._buildings_schema_file = os.path.join(mfscfg.MFS_TEMPLATES_DIR, self._buildings_schema_file)  # type: ignore
+
     def set_components_by_names(self, component_names: list[str]) -> None:
         """Sets the components used for map generation by their names.
 
@@ -159,6 +167,19 @@ class Game:
             raise ValueError("Tree layers schema path not set.")
         return self._tree_schema
 
+    @property
+    def buildings_schema(self) -> str:
+        """Returns the path to the buildings layers schema file.
+
+        Raises:
+            ValueError: If the buildings layers schema path is not set.
+
+        Returns:
+            str: The path to the buildings layers schema file."""
+        if not self._buildings_schema_file:
+            raise ValueError("Buildings layers schema path not set.")
+        return self._buildings_schema_file
+
     def dem_file_path(self, map_directory: str) -> str:
         """Returns the path to the DEM file.
 
@@ -166,8 +187,7 @@ class Game:
             map_directory (str): The path to the map directory.
 
         Returns:
-            str: The path to the DEM file.
-        """
+            str: The path to the DEM file."""
         raise NotImplementedError
 
     def weights_dir_path(self, map_directory: str) -> str:
@@ -341,6 +361,45 @@ class Game:
             bool: True if the mesh should be processed, False otherwise."""
         return self._mesh_processing
 
+    def validate_template(self, map_directory: str) -> None:
+        """Validates that all required files exist in the map template directory.
+
+        Arguments:
+            map_directory (str): The path to the map directory.
+
+        Raises:
+            FileNotFoundError: If any required files are missing from the template.
+        """
+        all_files = []
+        for root, _, files in os.walk(map_directory):
+            for file in files:
+                all_files.append(os.path.join(root, file))
+
+        missing_files = []
+        for func in self.required_file_methods():
+            try:
+                required_filepath = func(map_directory)
+            except NotImplementedError:
+                continue
+            if required_filepath not in all_files:
+                missing_files.append(required_filepath)
+        if missing_files:
+            raise FileNotFoundError(f"The following files are not found: {missing_files}.")
+
+    def required_file_methods(self) -> list[Callable[[str], str]]:
+        """Returns a list of methods that return paths to required files for map generation.
+
+        Returns:
+            list[Callable[[str], str]]: List of methods that take a map directory path
+                and return file paths that are required for the map template.
+        """
+        return [
+            self.map_xml_path,
+            self.i3d_file_path,
+            self.get_environment_xml_path,
+            self.get_farmlands_xml_path,
+        ]
+
 
 class FS22(Game):
     """Class used to define the game version FS22."""
@@ -396,6 +455,7 @@ class FS25(Game):
     _texture_schema_file = "fs25-texture-schema.json"
     _grle_schema_file = "fs25-grle-schema.json"
     _tree_schema_file = "fs25-tree-schema.json"
+    _buildings_schema_file = "fs25-buildings-schema.json"
 
     def dem_file_path(self, map_directory: str) -> str:
         """Returns the path to the DEM file.
